summaryrefslogtreecommitdiff
path: root/vp9/decoder
diff options
context:
space:
mode:
authorYaowu Xu <yaowu@google.com>2013-04-11 12:16:35 -0700
committerYaowu Xu <yaowu@google.com>2013-04-12 09:23:58 -0700
commit7de5edd14adebee3b931e9b132ab22fd8e2f2aa7 (patch)
tree93165fb4558ee9aaa2b86be46d704237f79fa2bf /vp9/decoder
parentaa25f6a3dff04e3453601bd041fbe3b011f92deb (diff)
downloadlibvpx-7de5edd14adebee3b931e9b132ab22fd8e2f2aa7.tar
libvpx-7de5edd14adebee3b931e9b132ab22fd8e2f2aa7.tar.gz
libvpx-7de5edd14adebee3b931e9b132ab22fd8e2f2aa7.tar.bz2
libvpx-7de5edd14adebee3b931e9b132ab22fd8e2f2aa7.zip
Rename B_PRED to I4X4_PRED
So it is consistent with I8x8_PRED. Change-Id: Iefa65124b2419690d83e526c611129c0ede29d11
Diffstat (limited to 'vp9/decoder')
-rw-r--r--vp9/decoder/vp9_decodemv.c10
-rw-r--r--vp9/decoder/vp9_decodframe.c8
2 files changed, 9 insertions, 9 deletions
diff --git a/vp9/decoder/vp9_decodframe.c b/vp9/decoder/vp9_decodframe.c
index e952cc73a..2f702433b 100644
--- a/vp9/decoder/vp9_decodframe.c
+++ b/vp9/decoder/vp9_decodframe.c
@@ -369,7 +369,7 @@ static void decode_4x4(VP9D_COMP *pbi, MACROBLOCKD *xd,
*(b->base_dst) + b->dst, b->dst_stride, b->dst_stride,
xd->plane[2].eobs[i]);
}
- } else if (mode == B_PRED) {
+ } else if (mode == I4X4_PRED) {
for (i = 0; i < 16; i++) {
BLOCKD *b = &xd->block[i];
int b_mode = xd->mode_info_context->bmi[i].as_mode.first;
@@ -770,7 +770,7 @@ static void decode_mb(VP9D_COMP *pbi, MACROBLOCKD *xd,
vp9_reset_sb_tokens_context(xd, BLOCK_SIZE_MB16X16);
} else if (!bool_error(bc)) {
#if CONFIG_NEWBINTRAMODES
- if (mode != B_PRED)
+ if (mode != I4X4_PRED)
#endif
eobtotal = vp9_decode_tokens(pbi, xd, bc, BLOCK_SIZE_MB16X16);
}
@@ -781,7 +781,7 @@ static void decode_mb(VP9D_COMP *pbi, MACROBLOCKD *xd,
&pbi->common);
if (eobtotal == 0 &&
- mode != B_PRED &&
+ mode != I4X4_PRED &&
mode != SPLITMV &&
mode != I8X8_PRED &&
!bool_error(bc)) {
@@ -804,7 +804,7 @@ static void decode_mb(VP9D_COMP *pbi, MACROBLOCKD *xd,
if (xd->mode_info_context->mbmi.ref_frame == INTRA_FRAME) {
if (mode != I8X8_PRED) {
vp9_build_intra_predictors_sbuv_s(xd, BLOCK_SIZE_MB16X16);
- if (mode != B_PRED)
+ if (mode != I4X4_PRED)
vp9_build_intra_predictors_sby_s(xd, BLOCK_SIZE_MB16X16);
}
} else {
diff --git a/vp9/decoder/vp9_decodemv.c b/vp9/decoder/vp9_decodemv.c
index 27cd6a9a9..60ef89118 100644
--- a/vp9/decoder/vp9_decodemv.c
+++ b/vp9/decoder/vp9_decodemv.c
@@ -171,7 +171,7 @@ static void kfread_modes(VP9D_COMP *pbi,
m->mbmi.ref_frame = INTRA_FRAME;
- if ((m->mbmi.mode = y_mode) == B_PRED) {
+ if ((m->mbmi.mode = y_mode) == I4X4_PRED) {
int i = 0;
do {
const B_PREDICTION_MODE a = above_block_mode(m, i, mis);
@@ -214,7 +214,7 @@ static void kfread_modes(VP9D_COMP *pbi,
m->mbmi.txfm_size = TX_32X32;
} else if (cm->txfm_mode >= ALLOW_16X16 && m->mbmi.mode <= TM_PRED) {
m->mbmi.txfm_size = TX_16X16;
- } else if (cm->txfm_mode >= ALLOW_8X8 && m->mbmi.mode != B_PRED) {
+ } else if (cm->txfm_mode >= ALLOW_8X8 && m->mbmi.mode != I4X4_PRED) {
m->mbmi.txfm_size = TX_8X8;
} else {
m->mbmi.txfm_size = TX_4X4;
@@ -1065,8 +1065,8 @@ static void read_mb_modes_mv(VP9D_COMP *pbi, MODE_INFO *mi, MB_MODE_INFO *mbmi,
pbi->common.fc.ymode_counts[mbmi->mode]++;
}
- // If MB mode is BPRED read the block modes
- if (mbmi->mode == B_PRED) {
+ // If MB mode is I4X4_PRED read the block modes
+ if (mbmi->mode == I4X4_PRED) {
int j = 0;
do {
int m = read_bmode(bc, pbi->common.fc.bmode_prob);
@@ -1120,7 +1120,7 @@ static void read_mb_modes_mv(VP9D_COMP *pbi, MODE_INFO *mi, MB_MODE_INFO *mbmi,
(mbmi->ref_frame != INTRA_FRAME && mbmi->mode != SPLITMV))) {
mbmi->txfm_size = TX_16X16;
} else if (cm->txfm_mode >= ALLOW_8X8 &&
- (!(mbmi->ref_frame == INTRA_FRAME && mbmi->mode == B_PRED) &&
+ (!(mbmi->ref_frame == INTRA_FRAME && mbmi->mode == I4X4_PRED) &&
!(mbmi->ref_frame != INTRA_FRAME && mbmi->mode == SPLITMV &&
mbmi->partitioning == PARTITIONING_4X4))) {
mbmi->txfm_size = TX_8X8;